# Physiology-Analysis-Tools
Tools for analysis and visualization of physiological signals (ECG, EEG, EMG, BP, Plethysmography, Pneumotachography, Video, ...)

This software was driven by efforts of the Cardiovascular and Metabolism Working Group of the International Mouse Phenotyping Consortium. 
It is intended to be a Free and Open Source Software Solution to aid in the analysis of physiological signals.

# What is it?
Physiology-Analysis-Tools is a toolkit for analysis and visualization of physiological signals which may have been acquired by a variety of vendors/equipment. 
 * The signals that are intended to be processed include:
 - [x] ECG
 - [ ] EEG
 - [ ] EMG
 - [ ] Blood Pressure
 - [ ] Body Temperature
 - [ ] Plethysmography
 - [ ] Pneumotachography
 - [ ] Video
 * The outcome measures that are intended to be identified include:
 - [x] Heart Rate
 - [ ] ECG waveform components (PQRST)
 - [x] Arrhythmia
 - [ ] Systolic, Diastolic, and Mean Blood Pressure
 - [ ] Breathing Rate
 - [ ] Activity

# Where to get it?
  * Install it with pip!
    * https://pypi.org/project/physiology-analysis-tools/
    * <code>pip install physiology_analysis_tools</code>

  * Install it from source code
    * https://github.com/realchrisward/Physiology-Analysis-Tools/


# How to use it?
1. download and install <code>pip install physiology_analysis_tools</code>
1. launch the program <code>python -m physiology_analysis_tools.main</code>
1. import your signal files (e.g. ECG traces)
1. detect basic features (e.g. heartbeats from ECG traces)
1. detect advanced features (e.g. arrhythmias)
1. export your data report
1. repeat!

# Licensing
'Physiology-Analysis-Tools' is currently developed under a 'GPLv3 or later' license, and may be made available under alternative licences upon request and suitable agreement (inquiries for alternative licensing may be directed to christopher.ward@bcm.edu). Compiled and Packaged versions may be made available under different licenses that will be defined at the time of release. 

    Physiology Analysis Tools
    Copyright (C) 2023  
    Christopher Scott Ward.
    with contributions from the IMPC Cardiovascular and Metabolism 
    Working Group.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.

# Contributions
Contribution License Agreement (Adapted from Harmony Individual Contributor License Agreement (HA-CLA-I) 1, Version 1.0 July 4, 2011)
    
    Contributions.1 Copyright License
    (a) You retain ownership of the Copyright in Your Contribution and 
    have the same rights to use or license the Contribution which You 
    would have had without entering into the Agreement.
    (b) To the maximum extent permitted by the relevant law, You grant 
    to Us a perpetual, worldwide, nonexclusive, transferable, 
    royalty-free, irrevocable license under the Copyright covering the 
    Contribution, with the right to sublicense such rights through 
    multiple tiers of sublicensees, to reproduce, modify, display, 
    perform and distribute the Contribution as part of the Material; 
    provided that this license is conditioned upon compliance with 
    Section 2.3.
    
    Contributions.2 Patent License
    For patent claims including, without limitation, method, process, 
    and apparatus claims which You [or Your Affiliates] own, control or 
    have the right to grant, now or in the future, You grant to Us a 
    perpetual, worldwide, non-exclusive, transferable, royalty-free, 
    irrevocable patent license, with the right to sublicense these rights 
    to multiple tiers of sublicensees, to make, have made, use, sell, 
    offer for sale, import and otherwise transfer the Contribution and 
    the Contribution in combination with the Material (and portions of 
    such combination). This license is granted only to the extent that 
    the exercise of the licensed rights infringes such patent claims; and 
    provided that this license is conditioned upon compliance with 
    Section 2.3.
    
    Contributions.3 Outbound License
    Based on the grant of rights in Sections 2.1 and 2.2, if We include 
    Your Contribution in a Material, We may license the Contribution 
    under any license, including copyleft, permissive, commercial, or 
    proprietary licenses. As a condition on the exercise of this right, 
    We agree to also license the Contribution under the terms of the 
    license or licenses which We are using for the Material on the 
    Submission Date.
    
    Contributions.4 Moral Rights. 
    If moral rights apply to the Contribution, to the maximum extent 
    permitted by law, You waive and agree not to assert such moral rights 
    against Us or our successors in interest, or any of our licensees, 
    either direct or indirect.
    
    Contributions.5 Our Rights. 
    You acknowledge that We are not obligated to use Your Contribution as 
    part of the Material and may decide to include any Contribution We 
    consider appropriate.
    
    Contributions.6 Reservation of Rights. 
    Any rights not expressly licensed under this section are expressly 
    reserved by You.

